summaryrefslogtreecommitdiff
path: root/evrpc.h
diff options
context:
space:
mode:
authorNiels Provos <provos@gmail.com>2008-05-01 01:45:00 +0000
committerNiels Provos <provos@gmail.com>2008-05-01 01:45:00 +0000
commit85c4904bc526103e5702c716ee80d03937083168 (patch)
tree41a89161e3bcef37b8684b965c7ae15c00a04c46 /evrpc.h
parentd76cca72736a0918221506c64d76124e65a71f1a (diff)
downloadlibevent-85c4904bc526103e5702c716ee80d03937083168.tar.gz
allow connections to be removed from an rpc pool
svn:r753
Diffstat (limited to 'evrpc.h')
-rw-r--r--evrpc.h26
1 files changed, 21 insertions, 5 deletions
diff --git a/evrpc.h b/evrpc.h
index 26359187..f7f17134 100644
--- a/evrpc.h
+++ b/evrpc.h
@@ -430,12 +430,28 @@ struct evrpc_pool *evrpc_pool_new(struct event_base *base);
* @see evrpc_pool_new()
*/
void evrpc_pool_free(struct evrpc_pool *pool);
-/*
- * adds a connection over which rpc can be dispatched. the connection
- * object must have been newly created.
+
+/**
+ * Adds a connection over which rpc can be dispatched to the pool.
+ *
+ * The connection object must have been newly created.
+ *
+ * @param pool the pool to which to add the connection
+ * @param evcon the connection to add to the pool.
+ */
+void evrpc_pool_add_connection(struct evrpc_pool *pool,
+ struct evhttp_connection *evcon);
+
+/**
+ * Removes a connection from the pool.
+ *
+ * The connection object must have been newly created.
+ *
+ * @param pool the pool from which to remove the connection
+ * @param evcon the connection to remove from the pool.
*/
-void evrpc_pool_add_connection(struct evrpc_pool *,
- struct evhttp_connection *);
+void evrpc_pool_remove_connection(struct evrpc_pool *pool,
+ struct evhttp_connection *evcon);
/**
* Sets the timeout in secs after which a request has to complete. The